summaryrefslogtreecommitdiffstats
path: root/client
diff options
context:
space:
mode:
authorAhmed Ashour <asashour@yahoo.com>2017-10-10 13:14:59 +0200
committerTeemu Suo-Anttila <tsuoanttila@users.noreply.github.com>2017-10-10 14:14:59 +0300
commitfa62729e243df9cea8fd3c93cf10a96b7f9c713c (patch)
tree6f905e6f8c50048805edd6444f261e718c9576ab /client
parentab18b6c58ef819dbc0049c4713cf06209d5abc47 (diff)
downloadvaadin-framework-fa62729e243df9cea8fd3c93cf10a96b7f9c713c.tar.gz
vaadin-framework-fa62729e243df9cea8fd3c93cf10a96b7f9c713c.zip
Fix typos (#10158)
Diffstat (limited to 'client')
-rw-r--r--client/src/main/java/com/vaadin/client/LocaleService.java2
-rw-r--r--client/src/main/java/com/vaadin/client/ui/VAbstractCalendarPanel.java4
-rw-r--r--client/src/main/java/com/vaadin/client/ui/VAbstractPopupCalendar.java22
-rw-r--r--client/src/main/java/com/vaadin/client/ui/VDateTimeCalendarPanel.java2
-rw-r--r--client/src/main/java/com/vaadin/client/widgets/Escalator.java2
-rwxr-xr-xclient/src/main/java/com/vaadin/client/widgets/Grid.java2
6 files changed, 17 insertions, 17 deletions
diff --git a/client/src/main/java/com/vaadin/client/LocaleService.java b/client/src/main/java/com/vaadin/client/LocaleService.java
index 01fbeb4d2c..b877bca7c5 100644
--- a/client/src/main/java/com/vaadin/client/LocaleService.java
+++ b/client/src/main/java/com/vaadin/client/LocaleService.java
@@ -25,7 +25,7 @@ import java.util.logging.Logger;
import com.vaadin.shared.ui.ui.UIState.LocaleData;
/**
- * Date / time etc. localisation service for all widgets. Caches all loaded
+ * Date / time etc. localization service for all widgets. Caches all loaded
* locales as JSONObjects.
*
* @author Vaadin Ltd.
diff --git a/client/src/main/java/com/vaadin/client/ui/VAbstractCalendarPanel.java b/client/src/main/java/com/vaadin/client/ui/VAbstractCalendarPanel.java
index f39210a6fd..3d8aa14862 100644
--- a/client/src/main/java/com/vaadin/client/ui/VAbstractCalendarPanel.java
+++ b/client/src/main/java/com/vaadin/client/ui/VAbstractCalendarPanel.java
@@ -234,7 +234,7 @@ public abstract class VAbstractCalendarPanel<R extends Enum<R>>
* one of the days currently visible.
*/
private void focusDay(Date date) {
- // Only used when calender body is present
+ // Only used when calendar body is present
if (acceptDayFocus()) {
if (focusedDay != null) {
focusedDay.removeStyleDependentName(CN_FOCUSED);
@@ -1775,7 +1775,7 @@ public abstract class VAbstractCalendarPanel<R extends Enum<R>>
/**
* The submit listener is called when the user selects a value from the
- * calender either by clicking the day or selects it by keyboard.
+ * calendar either by clicking the day or selects it by keyboard.
*
* @param submitListener
* The listener to trigger
diff --git a/client/src/main/java/com/vaadin/client/ui/VDateTimeCalendarPanel.java b/client/src/main/java/com/vaadin/client/ui/VDateTimeCalendarPanel.java
index 0c2dfc8628..55922e4825 100644
--- a/client/src/main/java/com/vaadin/client/ui/VDateTimeCalendarPanel.java
+++ b/client/src/main/java/com/vaadin/client/ui/VDateTimeCalendarPanel.java
@@ -46,7 +46,7 @@ public class VDateTimeCalendarPanel
private VTime time;
/**
- * TimeSelector is a widget consisting of list boxes that modifie the Date
+ * TimeSelector is a widget consisting of list boxes that modify the Date
* object that is given for.
*
*/
diff --git a/client/src/main/java/com/vaadin/client/widgets/Escalator.java b/client/src/main/java/com/vaadin/client/widgets/Escalator.java
index 640304e828..cd5464a1cc 100644
--- a/client/src/main/java/com/vaadin/client/widgets/Escalator.java
+++ b/client/src/main/java/com/vaadin/client/widgets/Escalator.java
@@ -283,7 +283,7 @@ public class Escalator extends Widget
// todo comments legend
/*
* [[optimize]]: There's an opportunity to rewrite the code in such a way
- * that it _might_ perform better (rememeber to measure, implement,
+ * that it _might_ perform better (remember to measure, implement,
* re-measure)
*/
/*
diff --git a/client/src/main/java/com/vaadin/client/widgets/Grid.java b/client/src/main/java/com/vaadin/client/widgets/Grid.java
index 80c7e354c7..5c3978c6a3 100755
--- a/client/src/main/java/com/vaadin/client/widgets/Grid.java
+++ b/client/src/main/java/com/vaadin/client/widgets/Grid.java
@@ -6976,7 +6976,7 @@ public class Grid<T> extends ResizeComposite implements HasSelectionHandlers<T>,
}
/**
- * Gets the {@link Escalator} used by this Grid instnace.
+ * Gets the {@link Escalator} used by this Grid instance.
*
* @return the escalator instance, never <code>null</code>
*/
diff --git a/client/src/main/java/com/vaadin/client/ui/VAbstractPopupCalendar.java b/client/src/main/java/com/vaadin/client/ui/VAbstractPopupCalendar.java
index 3799a8aff8..69da64a86c 100644
--- a/client/src/main/java/com/vaadin/client/ui/VAbstractPopupCalendar.java
+++ b/client/src/main/java/com/vaadin/client/ui/VAbstractPopupCalendar.java
@@ -96,7 +96,7 @@ public abstract class VAbstractPopupCalendar<PANEL extends VAbstractCalendarPane
private Label selectedDate;
- private Element descriptionForAssisitveDevicesElement;
+ private Element descriptionForAssistiveDevicesElement;
private final String CALENDAR_TOGGLE_ID = "popupButton";
@@ -129,15 +129,15 @@ public abstract class VAbstractPopupCalendar<PANEL extends VAbstractCalendarPane
add(calendarToggle);
- // Description of the usage of the widget for assisitve device users
- descriptionForAssisitveDevicesElement = DOM.createDiv();
- descriptionForAssisitveDevicesElement.setInnerText(
+ // Description of the usage of the widget for assistive device users
+ descriptionForAssistiveDevicesElement = DOM.createDiv();
+ descriptionForAssistiveDevicesElement.setInnerText(
TextualDateFieldState.DESCRIPTION_FOR_ASSISTIVE_DEVICES);
- AriaHelper.ensureHasId(descriptionForAssisitveDevicesElement);
+ AriaHelper.ensureHasId(descriptionForAssistiveDevicesElement);
Roles.getTextboxRole().setAriaDescribedbyProperty(text.getElement(),
- Id.of(descriptionForAssisitveDevicesElement));
+ Id.of(descriptionForAssistiveDevicesElement));
AriaHelper.setVisibleForAssistiveDevicesOnly(
- descriptionForAssisitveDevicesElement, true);
+ descriptionForAssistiveDevicesElement, true);
calendar = calendarPanel;
calendar.setParentField(this);
@@ -207,13 +207,13 @@ public abstract class VAbstractPopupCalendar<PANEL extends VAbstractCalendarPane
protected void onAttach() {
super.onAttach();
DOM.appendChild(RootPanel.get().getElement(),
- descriptionForAssisitveDevicesElement);
+ descriptionForAssistiveDevicesElement);
}
@Override
protected void onDetach() {
super.onDetach();
- descriptionForAssisitveDevicesElement.removeFromParent();
+ descriptionForAssistiveDevicesElement.removeFromParent();
closeCalendarPanel();
}
@@ -583,7 +583,7 @@ public abstract class VAbstractPopupCalendar<PANEL extends VAbstractCalendarPane
*/
public void setDescriptionForAssistiveDevices(
String descriptionForAssistiveDevices) {
- descriptionForAssisitveDevicesElement
+ descriptionForAssistiveDevicesElement
.setInnerText(descriptionForAssistiveDevices);
}
@@ -594,7 +594,7 @@ public abstract class VAbstractPopupCalendar<PANEL extends VAbstractCalendarPane
* @return String with the description
*/
public String getDescriptionForAssistiveDevices() {
- return descriptionForAssisitveDevicesElement.getInnerText();
+ return descriptionForAssistiveDevicesElement.getInnerText();
}
/**